

clear all
close all

lag=0.0;
wsem = load('..\data\Girond_WSE.txt');
um = load('..\data\Girond_Vel.txt');
wsec = load('..\data\Calculated_wse.txt');
uc = load('..\data\Calculated_vel.txt');


%% Plotting water level
name{1} = 'Richard';
name{2} = 'Lamena';
name{3} = 'Pauillac';
name{4} = 'Ile Verte';
name{5} = 'La Reuile';

rmse = zeros(5,1);
nrmse = zeros(5,1);
nmae = zeros(5,1);
R2 = zeros(5,1);
bias = zeros(5,1);

ind = [1 2 3 4 5];

figure('position',[361    42   490   641])
for i=1:5
    %figure('position',[1657  309  551   257])
    subplot(5,1,i)
    plot(wsem(:,1),wsem(:,i+1),'o','markerfacecolor','r','markeredgecolor','r')
    hold on
    plot(wsec(:,1)-lag,wsec(:,ind(i)+1),'b','linewidth',2)
    set(gca,'ylim',[-3 3],'xlim',[5 55])    
    title(name{i})
    if i==5
        xlabel('Time Elapsed, hr')
    end
    ylabel('Water Level, m')
    
    %Statistics
    xm = wsem(:,1); ym = wsem(:,i+1);
    xc = wsec(:,1)-lag; yc = wsec(:,ind(i)+1);
    yc = interp1(xc,yc,xm);
    ii = (isfinite(yc) & xm>10);
    ym = ym(ii); yc = yc(ii);    
    rmse(i) = sqrt(mean((yc-ym).^2));
    nrmse(i) = sqrt(mean((yc-ym).^2))/(max(ym)-min(ym));
    nmae(i) = mean(abs((yc-ym)))/(max(ym)-min(ym));
    R = corrcoef(yc,ym);
    R2(i) = R(1,2).^2;
    bias(i) = mean(yc-ym);
end

disp('--- Gironde Water Level Goodness of fit statistics ---')
disp('Station    1       2       3       4      5')
fprintf(1,'RMSE    %7.4f,%7.4f,%7.4f,%7.4f,%7.4f\n',rmse);
fprintf(1,'NRMSE    %7.4f,%7.4f,%7.4f,%7.4f,%7.4f\n',nrmse);
fprintf(1,'NMAE    %7.4f,%7.4f,%7.4f,%7.4f,%7.4f\n',nmae);
fprintf(1,'R^2     %7.3f,%7.3f,%7.3f,%7.3f,%7.4f\n',R2);
fprintf(1,'Bias     %7.3f,%7.3f,%7.3f,%7.3f,%7.4f\n',bias);


%% Plotting velocity
name{1} = 'Richard';
name{2} = 'PK68';
name{3} = 'Lamena';
name{4} = 'Pauillac-1';
name{5} = 'Pauillac-2';
name{6} = 'Blaye';

rmse = zeros(6,1);
nrmse = zeros(6,1);
nmae = zeros(6,1);
R2 = zeros(6,1);
bias = zeros(6,1);

ind2 = [1 2 3 4 5 6];

figure('position',[566   130   516   529])
for i=1:6
    %figure('position',[1657  309  551   257])
    subplot(3,2,i)    
    plot(um(:,1),um(:,i*2),'o','markerfacecolor','r','markeredgecolor','r')
    hold on
    plot(um(:,1),um(:,i*2+1),'d','markerfacecolor','g','markeredgecolor','g')
    plot(uc(:,1)-lag,uc(:,ind2(i)+1),'b','linewidth',2)
    set(gca,'ylim',[-3 3],'xlim',[76 92],'box','on')    
    title(name{i})
    if i==5 || i==6
        xlabel('Time Elapsed, hr')        
    end
    if i==6
        legend('Measured 1m below surface','Measured 1m above bottom','Calculated')
    end
    if i==1 || i==3 || i==5
        ylabel('Current Velocity, m/s')
    end
    
    
    %Statistics
    xm = um(:,1); ym = um(:,i*2);
    xc = uc(:,1)-lag; yc = uc(:,ind2(i)+1);
    yc = interp1(xc,yc,xm);
    ii = (isfinite(yc) & xm>10);
    ym = ym(ii); yc = yc(ii);    
    rmse(i) = sqrt(mean((yc-ym).^2));
    nrmse(i) = sqrt(mean((yc-ym).^2))/(max(ym)-min(ym));
    nmae(i) = mean(abs((yc-ym)))/(max(ym)-min(ym));
    R = corrcoef(yc,ym);
    R2(i) = R(1,2).^2;
    bias(i) = mean(yc-ym);
%     figure
%     plot(ym,yc,'.')
end

disp('--- Gironde Velocity Goodness of fit statistics ---')
disp('Station    1       2       3       4        5      6')
fprintf(1,'RMSE    %7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f\n',rmse);
fprintf(1,'NRMSE    %7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f\n',nrmse);
fprintf(1,'NMAE    %7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f\n',nmae);
fprintf(1,'R^2     %7.3f,%7.3f,%7.3f,%7.3f,%7.4f,%7.4f\n',R2);
fprintf(1,'Bias     %7.3f,%7.3f,%7.3f,%7.3f,%7.4f,%7.4f\n',bias);



